Environment

Struct Environment 

pub struct Environment {
    pub locale: Signal<LanguageIdentifier>,
    pub direction: Signal<Direction>,
    pub double_click_interval: Duration,
    pub tooltip_delay: Duration,
    pub theme_mode: ThemeMode,
    pub system_theme_mode: ThemeMode,
    pub drag_distance: Signal<u32>,
    pub debug_layout: bool,
    /* private fields */
}
A model for system specific state which can be accessed by any model or view.

Fields

locale: Signal<LanguageIdentifier>

The locale used for localization.

direction: Signal<Direction>

The text and layout direction used by the application.

double_click_interval: Duration

The maximum interval between two clicks to be recognised as a double-click.

tooltip_delay: Duration

The delay before a tooltip fades in.

theme_mode: ThemeMode

The user’s theme preference (may be System to follow the OS).

system_theme_mode: ThemeMode

The OS-reported system theme (always DarkMode or LightMode, never System).

drag_distance: Signal<u32>

The distance the mouse has to be dragged to start a drag operation.

debug_layout: bool

Whether the layout debug overlay is enabled. When set, views which underwent layout in the most recent layout pass are outlined in orange until the next layout pass.

Implementations

Source

impl Environment

pub fn effective_theme(&self) -> ThemeMode

Returns the effective (resolved) theme, substituting the OS theme when the user preference is ThemeMode::System.